<?php
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@advcs.org
    Home Site ...... http://advcs.org
    Program ........ Notes
    Version ........ 1.0
    Purpose ........ Storing Notes

*******************************************************************************/

function squirrelmail_plugin_init_notes() {
   global $squirrelmail_plugin_hooks;
   $squirrelmail_plugin_hooks['menuline']['notes'] = 'notes';
}

function notes() {
   //Add Notes link to upper menu
   displayInternalLink('plugins/notes/notes.php',_('Notes'),'right');
   echo "&nbsp;&nbsp\n";
}

function notes_version() { 
   return '1.0';
}

?>
